@@ -258,6 +258,14 @@ sub io_independent_tests {
     is_deeply( $root_3->_paginate( { name => 'array', limit => 1, skip => 4, reverse => 1 } ), [ 'With more than one thing' ], 'paginate limit 1 from 4' );
     is_deeply( $root_3->_paginate( { name => 'array', limit => 3, skip => 4 } ), [ 'MORE STUFF','MORE STUFF' ], 'paginate limit 3 from 4' );
     is_deeply( $root_3->_paginate( { name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
+    is_deeply( $root_3->_paginate( { sort_fields => [], name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
+    is_deeply( $root_3->_paginate( { search_fields => [], name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
+    is_deeply( $root_3->_paginate( { search_terms => [], name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
+    is_deeply( $root_3->_paginate( { search_values => [], name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
+    is_deeply( $root_3->_paginate( { search_terms => [], search_values => [], name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
+    is_deeply( $root_3->_paginate( { sort_fields => [], search_terms => [], search_values => [], name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
+    is_deeply( $root_3->_paginate( { sort_fields => [], search_terms => [], name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
+    is_deeply( $root_3->_paginate( { sort_fields => [], search_values => [], name => 'array', limit => 3, skip => 4, reverse => 1 } ), [ 'With more than one thing', 'THIS IS AN ARRAY' ], 'paginate limit 3 from 4 reversed' );
 
     # unified pagination test
     is_deeply( $root_3->_paginate( { name => 'array', limit => 3 } ), [ 'THIS IS AN ARRAY', 'With more than one thing', 'MORE STUFF' ], 'paginate with length limit' );
@@ -682,6 +690,39 @@ sub io_independent_tests {
     is( 3, @$res, "pag sort 3 results" );
     is_deeply( \@ids, [ map { $_->{ID} } @$res ], "Got correct pag sort order" );
 
+    is( $o->count( { name => 'searchlist', search_fields => [], search_terms=> [] } ), @$searchlist, "count gets correct count with empty search fields and search terms" );
+    is( $o->count( { name => 'searchlist', search_fields=> [] } ), @$searchlist, "count gets correct count with empty search fields  terms" );
+    is( $o->count( { name => 'searchlist', search_terms=> [] } ), @$searchlist, "count gets correct count with empty  search terms" );
+
+
+    $res = $o->paginate( { name => 'searchlist', search_fields => [], search_terms=> [] } );
+    @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 1, 2, 3, 4, 5 );
+    is_deeply( \@ids, [ map { $_->{ID} } @$res ], "empty search fields and search terms no problemo" );
+
+    $res = $o->paginate( { name => 'searchlist', search_fields => [], search_terms=> [], sort_fields => [] } );
+    @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 1, 2, 3, 4, 5 );
+    is_deeply( \@ids, [ map { $_->{ID} } @$res ], "empty search fields and search terms and sort_fields no problemo" );
+
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [] } );
+    @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 1, 2, 3, 4, 5 );
+    is_deeply( \@ids, [ map { $_->{ID} } @$res ], "empty sort_fields no problemo" );
+
+    $res = $o->paginate( { name => 'searchlist', search_fields => [] } );
+    @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 1, 2, 3, 4, 5 );
+    is_deeply( \@ids, [ map { $_->{ID} } @$res ], "empty  search fields no problemo" );
+
+    $res = $o->paginate( { name => 'searchlist', search_terms => [] } );
+    @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 1, 2, 3, 4, 5 );
+    is_deeply( \@ids, [ map { $_->{ID} } @$res ], "empty  search terms no problemo" );
+
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [], search_fields => [] } );
+    @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 1, 2, 3, 4, 5 );
+    is_deeply( \@ids, [ map { $_->{ID} } @$res ], "empty  search fields and sort_fields no problemo" );
+
+    $res = $o->paginate( { name => 'searchlist', sort_fields => [], search_terms => [] } );
+    @ids = map { $searchlist->[ $_ ]->{ID} } ( 0, 1, 2, 3, 4, 5 );
+    is_deeply( \@ids, [ map { $_->{ID} } @$res ], "empty  search terms and sort_fields no problemo" );
+
     # test add_to, count, delete_key, hash, insert_at, list_fetch, remove_from
     $o = new Yote::Obj( { anonymous => "guest" } );
     Yote::ObjProvider::stow_all();
