@@ -8,6 +8,12 @@ use warnings;
 
 use base 'Yote::Obj';
 
+sub new_with_same_permissions {
+    my( $self, $dummy, $account ) = @_;
+    die "Permissions Error" unless $self->_check_access( $account, 1, '' );
+    return new Yote::RootObj();
+} #new_with_same_permissions
+
 # only root may edit any fields. public fields are readable by all.
 sub _check_access {
     my( $self, $account, $write_access, $name ) = @_;
@@ -28,6 +34,16 @@ This is a subclass of Yote::Obj that allows root access of its public and privat
 and allows read access of its public fields for non root users. The Yote::YoteRoot instance method new_root_obj
 returns a new object of this type.
 
+=head2 METHODS
+
+=over 4
+
+=item new_with_same_permissions()
+
+Returns a new yote object with the same permissions as this.
+
+=back
+
 =head1 AUTHOR
 
 Eric Wolf
